Skip to contents

Sample metadata for the example_microbiome dataset, containing sample identifiers, sample types, and habitat classifications.

Usage

em_metadata

Format

A data frame with columns:

SampleID

Sample identifier

SampleType

Original sample type label

Habitat

Broad habitat category (Terrestrial, Oceanic, Freshwater, Brackish)

Description

Sample description)

@source Caporaso, J.G., et al. (2011). Global patterns of 16S rRNA diversity at a depth of millions of sequences per sample. PNAS, 108, 4516–4522. Available via phyloseq::GlobalPatterns.